# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiscoveryJobResult(object):
    """
    A discovery job result representing a sensitive column. It can be one of the following three types:
    NEW: A new sensitive column in the target database that is not in the sensitive data model.
    DELETED: A column that is present in the sensitive data model but has been deleted from the target database.
    MODIFIED: A column that is present in the target database as well as the sensitive data model but some of its attributes have been modified.
    """

    #: A constant which can be used with the discovery_type property of a DiscoveryJobResult.
    #: This constant has a value of "NEW"
    DISCOVERY_TYPE_NEW = "NEW"

    #: A constant which can be used with the discovery_type property of a DiscoveryJobResult.
    #: This constant has a value of "MODIFIED"
    DISCOVERY_TYPE_MODIFIED = "MODIFIED"

    #: A constant which can be used with the discovery_type property of a DiscoveryJobResult.
    #: This constant has a value of "DELETED"
    DISCOVERY_TYPE_DELETED = "DELETED"

    #: A constant which can be used with the object_type property of a DiscoveryJobResult.
    #: This constant has a value of "TABLE"
    OBJECT_TYPE_TABLE = "TABLE"

    #: A constant which can be used with the object_type property of a DiscoveryJobResult.
    #: This constant has a value of "EDITIONING_VIEW"
    OBJECT_TYPE_EDITIONING_VIEW = "EDITIONING_VIEW"

    #: A constant which can be used with the relation_type property of a DiscoveryJobResult.
    #: This constant has a value of "NONE"
    RELATION_TYPE_NONE = "NONE"

    #: A constant which can be used with the relation_type property of a DiscoveryJobResult.
    #: This constant has a value of "APP_DEFINED"
    RELATION_TYPE_APP_DEFINED = "APP_DEFINED"

    #: A constant which can be used with the relation_type property of a DiscoveryJobResult.
    #: This constant has a value of "DB_DEFINED"
    RELATION_TYPE_DB_DEFINED = "DB_DEFINED"

    #: A constant which can be used with the planned_action property of a DiscoveryJobResult.
    #: This constant has a value of "NONE"
    PLANNED_ACTION_NONE = "NONE"

    #: A constant which can be used with the planned_action property of a DiscoveryJobResult.
    #: This constant has a value of "ACCEPT"
    PLANNED_ACTION_ACCEPT = "ACCEPT"

    #: A constant which can be used with the planned_action property of a DiscoveryJobResult.
    #: This constant has a value of "INVALIDATE"
    PLANNED_ACTION_INVALIDATE = "INVALIDATE"

    #: A constant which can be used with the planned_action property of a DiscoveryJobResult.
    #: This constant has a value of "REJECT"
    PLANNED_ACTION_REJECT = "REJECT"

    def __init__(self, **kwargs):
        """
        Initializes a new DiscoveryJobResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this DiscoveryJobResult.
        :type key: str

        :param discovery_type:
            The value to assign to the discovery_type property of this DiscoveryJobResult.
            Allowed values for this property are: "NEW", "MODIFIED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type discovery_type: str

        :param sensitive_columnkey:
            The value to assign to the sensitive_columnkey property of this DiscoveryJobResult.
        :type sensitive_columnkey: str

        :param app_name:
            The value to assign to the app_name property of this DiscoveryJobResult.
        :type app_name: str

        :param schema_name:
            The value to assign to the schema_name property of this DiscoveryJobResult.
        :type schema_name: str

        :param object_name:
            The value to assign to the object_name property of this DiscoveryJobResult.
        :type object_name: str

        :param column_name:
            The value to assign to the column_name property of this DiscoveryJobResult.
        :type column_name: str

        :param object_type:
            The value to assign to the object_type property of this DiscoveryJobResult.
            Allowed values for this property are: "TABLE", "EDITIONING_VIEW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type object_type: str

        :param data_type:
            The value to assign to the data_type property of this DiscoveryJobResult.
        :type data_type: str

        :param sensitive_type_id:
            The value to assign to the sensitive_type_id property of this DiscoveryJobResult.
        :type sensitive_type_id: str

        :param parent_column_keys:
            The value to assign to the parent_column_keys property of this DiscoveryJobResult.
        :type parent_column_keys: list[str]

        :param relation_type:
            The value to assign to the relation_type property of this DiscoveryJobResult.
            Allowed values for this property are: "NONE", "APP_DEFINED", "DB_DEFINED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type relation_type: str

        :param estimated_data_value_count:
            The value to assign to the estimated_data_value_count property of this DiscoveryJobResult.
        :type estimated_data_value_count: int

        :param sample_data_values:
            The value to assign to the sample_data_values property of this DiscoveryJobResult.
        :type sample_data_values: list[str]

        :param app_defined_child_column_keys:
            The value to assign to the app_defined_child_column_keys property of this DiscoveryJobResult.
        :type app_defined_child_column_keys: list[str]

        :param db_defined_child_column_keys:
            The value to assign to the db_defined_child_column_keys property of this DiscoveryJobResult.
        :type db_defined_child_column_keys: list[str]

        :param planned_action:
            The value to assign to the planned_action property of this DiscoveryJobResult.
            Allowed values for this property are: "NONE", "ACCEPT", "INVALIDATE", "REJECT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type planned_action: str

        :param is_result_applied:
            The value to assign to the is_result_applied property of this DiscoveryJobResult.
        :type is_result_applied: bool

        :param modified_attributes:
            The value to assign to the modified_attributes property of this DiscoveryJobResult.
        :type modified_attributes: oci.data_safe.models.ModifiedAttributes

        """
        self.swagger_types = {
            'key': 'str',
            'discovery_type': 'str',
            'sensitive_columnkey': 'str',
            'app_name': 'str',
            'schema_name': 'str',
            'object_name': 'str',
            'column_name': 'str',
            'object_type': 'str',
            'data_type': 'str',
            'sensitive_type_id': 'str',
            'parent_column_keys': 'list[str]',
            'relation_type': 'str',
            'estimated_data_value_count': 'int',
            'sample_data_values': 'list[str]',
            'app_defined_child_column_keys': 'list[str]',
            'db_defined_child_column_keys': 'list[str]',
            'planned_action': 'str',
            'is_result_applied': 'bool',
            'modified_attributes': 'ModifiedAttributes'
        }

        self.attribute_map = {
            'key': 'key',
            'discovery_type': 'discoveryType',
            'sensitive_columnkey': 'sensitiveColumnkey',
            'app_name': 'appName',
            'schema_name': 'schemaName',
            'object_name': 'objectName',
            'column_name': 'columnName',
            'object_type': 'objectType',
            'data_type': 'dataType',
            'sensitive_type_id': 'sensitiveTypeId',
            'parent_column_keys': 'parentColumnKeys',
            'relation_type': 'relationType',
            'estimated_data_value_count': 'estimatedDataValueCount',
            'sample_data_values': 'sampleDataValues',
            'app_defined_child_column_keys': 'appDefinedChildColumnKeys',
            'db_defined_child_column_keys': 'dbDefinedChildColumnKeys',
            'planned_action': 'plannedAction',
            'is_result_applied': 'isResultApplied',
            'modified_attributes': 'modifiedAttributes'
        }

        self._key = None
        self._discovery_type = None
        self._sensitive_columnkey = None
        self._app_name = None
        self._schema_name = None
        self._object_name = None
        self._column_name = None
        self._object_type = None
        self._data_type = None
        self._sensitive_type_id = None
        self._parent_column_keys = None
        self._relation_type = None
        self._estimated_data_value_count = None
        self._sample_data_values = None
        self._app_defined_child_column_keys = None
        self._db_defined_child_column_keys = None
        self._planned_action = None
        self._is_result_applied = None
        self._modified_attributes = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this DiscoveryJobResult.
        The unique key that identifies the discovery result.


        :return: The key of this DiscoveryJobResult.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this DiscoveryJobResult.
        The unique key that identifies the discovery result.


        :param key: The key of this DiscoveryJobResult.
        :type: str
        """
        self._key = key

    @property
    def discovery_type(self):
        """
        **[Required]** Gets the discovery_type of this DiscoveryJobResult.
        The type of the discovery result. It can be one of the following three types:
        NEW: A new sensitive column in the target database that is not in the sensitive data model.
        DELETED: A column that is present in the sensitive data model but has been deleted from the target database.
        MODIFIED: A column that is present in the target database as well as the sensitive data model but some of its attributes have been modified.

        Allowed values for this property are: "NEW", "MODIFIED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The discovery_type of this DiscoveryJobResult.
        :rtype: str
        """
        return self._discovery_type

    @discovery_type.setter
    def discovery_type(self, discovery_type):
        """
        Sets the discovery_type of this DiscoveryJobResult.
        The type of the discovery result. It can be one of the following three types:
        NEW: A new sensitive column in the target database that is not in the sensitive data model.
        DELETED: A column that is present in the sensitive data model but has been deleted from the target database.
        MODIFIED: A column that is present in the target database as well as the sensitive data model but some of its attributes have been modified.


        :param discovery_type: The discovery_type of this DiscoveryJobResult.
        :type: str
        """
        allowed_values = ["NEW", "MODIFIED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(discovery_type, allowed_values):
            discovery_type = 'UNKNOWN_ENUM_VALUE'
        self._discovery_type = discovery_type

    @property
    def sensitive_columnkey(self):
        """
        Gets the sensitive_columnkey of this DiscoveryJobResult.
        The unique key that identifies the sensitive column represented by the discovery result.


        :return: The sensitive_columnkey of this DiscoveryJobResult.
        :rtype: str
        """
        return self._sensitive_columnkey

    @sensitive_columnkey.setter
    def sensitive_columnkey(self, sensitive_columnkey):
        """
        Sets the sensitive_columnkey of this DiscoveryJobResult.
        The unique key that identifies the sensitive column represented by the discovery result.


        :param sensitive_columnkey: The sensitive_columnkey of this DiscoveryJobResult.
        :type: str
        """
        self._sensitive_columnkey = sensitive_columnkey

    @property
    def app_name(self):
        """
        Gets the app_name of this DiscoveryJobResult.
        The name of the application. An application is an entity that is identified by a schema and stores sensitive information for that schema. Its value will be same as schemaName, if no value is passed.


        :return: The app_name of this DiscoveryJobResult.
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """
        Sets the app_name of this DiscoveryJobResult.
        The name of the application. An application is an entity that is identified by a schema and stores sensitive information for that schema. Its value will be same as schemaName, if no value is passed.


        :param app_name: The app_name of this DiscoveryJobResult.
        :type: str
        """
        self._app_name = app_name

    @property
    def schema_name(self):
        """
        **[Required]** Gets the schema_name of this DiscoveryJobResult.
        The database schema that contains the sensitive column.


        :return: The schema_name of this DiscoveryJobResult.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this DiscoveryJobResult.
        The database schema that contains the sensitive column.


        :param schema_name: The schema_name of this DiscoveryJobResult.
        :type: str
        """
        self._schema_name = schema_name

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this DiscoveryJobResult.
        The database object that contains the sensitive column.


        :return: The object_name of this DiscoveryJobResult.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this DiscoveryJobResult.
        The database object that contains the sensitive column.


        :param object_name: The object_name of this DiscoveryJobResult.
        :type: str
        """
        self._object_name = object_name

    @property
    def column_name(self):
        """
        **[Required]** Gets the column_name of this DiscoveryJobResult.
        The name of the sensitive column.


        :return: The column_name of this DiscoveryJobResult.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this DiscoveryJobResult.
        The name of the sensitive column.


        :param column_name: The column_name of this DiscoveryJobResult.
        :type: str
        """
        self._column_name = column_name

    @property
    def object_type(self):
        """
        **[Required]** Gets the object_type of this DiscoveryJobResult.
        The type of the database object that contains the sensitive column.

        Allowed values for this property are: "TABLE", "EDITIONING_VIEW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The object_type of this DiscoveryJobResult.
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """
        Sets the object_type of this DiscoveryJobResult.
        The type of the database object that contains the sensitive column.


        :param object_type: The object_type of this DiscoveryJobResult.
        :type: str
        """
        allowed_values = ["TABLE", "EDITIONING_VIEW"]
        if not value_allowed_none_or_none_sentinel(object_type, allowed_values):
            object_type = 'UNKNOWN_ENUM_VALUE'
        self._object_type = object_type

    @property
    def data_type(self):
        """
        **[Required]** Gets the data_type of this DiscoveryJobResult.
        The data type of the sensitive column.


        :return: The data_type of this DiscoveryJobResult.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this DiscoveryJobResult.
        The data type of the sensitive column.


        :param data_type: The data_type of this DiscoveryJobResult.
        :type: str
        """
        self._data_type = data_type

    @property
    def sensitive_type_id(self):
        """
        Gets the sensitive_type_id of this DiscoveryJobResult.
        The OCID of the sensitive type associated with the sensitive column.


        :return: The sensitive_type_id of this DiscoveryJobResult.
        :rtype: str
        """
        return self._sensitive_type_id

    @sensitive_type_id.setter
    def sensitive_type_id(self, sensitive_type_id):
        """
        Sets the sensitive_type_id of this DiscoveryJobResult.
        The OCID of the sensitive type associated with the sensitive column.


        :param sensitive_type_id: The sensitive_type_id of this DiscoveryJobResult.
        :type: str
        """
        self._sensitive_type_id = sensitive_type_id

    @property
    def parent_column_keys(self):
        """
        Gets the parent_column_keys of this DiscoveryJobResult.
        Unique keys identifying the columns that are parents of the sensitive column. At present, it tracks a single parent only.


        :return: The parent_column_keys of this DiscoveryJobResult.
        :rtype: list[str]
        """
        return self._parent_column_keys

    @parent_column_keys.setter
    def parent_column_keys(self, parent_column_keys):
        """
        Sets the parent_column_keys of this DiscoveryJobResult.
        Unique keys identifying the columns that are parents of the sensitive column. At present, it tracks a single parent only.


        :param parent_column_keys: The parent_column_keys of this DiscoveryJobResult.
        :type: list[str]
        """
        self._parent_column_keys = parent_column_keys

    @property
    def relation_type(self):
        """
        **[Required]** Gets the relation_type of this DiscoveryJobResult.
        The type of referential relationship the sensitive column has with its parent. NONE indicates that the sensitive
        column does not have a parent. DB_DEFINED indicates that the relationship is defined in the database dictionary.
        APP_DEFINED indicates that the relationship is defined at the application level and not in the database dictionary.

        Allowed values for this property are: "NONE", "APP_DEFINED", "DB_DEFINED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The relation_type of this DiscoveryJobResult.
        :rtype: str
        """
        return self._relation_type

    @relation_type.setter
    def relation_type(self, relation_type):
        """
        Sets the relation_type of this DiscoveryJobResult.
        The type of referential relationship the sensitive column has with its parent. NONE indicates that the sensitive
        column does not have a parent. DB_DEFINED indicates that the relationship is defined in the database dictionary.
        APP_DEFINED indicates that the relationship is defined at the application level and not in the database dictionary.


        :param relation_type: The relation_type of this DiscoveryJobResult.
        :type: str
        """
        allowed_values = ["NONE", "APP_DEFINED", "DB_DEFINED"]
        if not value_allowed_none_or_none_sentinel(relation_type, allowed_values):
            relation_type = 'UNKNOWN_ENUM_VALUE'
        self._relation_type = relation_type

    @property
    def estimated_data_value_count(self):
        """
        **[Required]** Gets the estimated_data_value_count of this DiscoveryJobResult.
        The estimated number of data values the column has in the associated database.


        :return: The estimated_data_value_count of this DiscoveryJobResult.
        :rtype: int
        """
        return self._estimated_data_value_count

    @estimated_data_value_count.setter
    def estimated_data_value_count(self, estimated_data_value_count):
        """
        Sets the estimated_data_value_count of this DiscoveryJobResult.
        The estimated number of data values the column has in the associated database.


        :param estimated_data_value_count: The estimated_data_value_count of this DiscoveryJobResult.
        :type: int
        """
        self._estimated_data_value_count = estimated_data_value_count

    @property
    def sample_data_values(self):
        """
        Gets the sample_data_values of this DiscoveryJobResult.
        Original data values collected for the sensitive column from the associated database. Sample data helps review
        the column and ensure that it actually contains sensitive data. Note that sample data is retrieved by a data
        discovery job only if the isSampleDataCollectionEnabled attribute is set to true. At present, only one data
        value is collected per sensitive column.


        :return: The sample_data_values of this DiscoveryJobResult.
        :rtype: list[str]
        """
        return self._sample_data_values

    @sample_data_values.setter
    def sample_data_values(self, sample_data_values):
        """
        Sets the sample_data_values of this DiscoveryJobResult.
        Original data values collected for the sensitive column from the associated database. Sample data helps review
        the column and ensure that it actually contains sensitive data. Note that sample data is retrieved by a data
        discovery job only if the isSampleDataCollectionEnabled attribute is set to true. At present, only one data
        value is collected per sensitive column.


        :param sample_data_values: The sample_data_values of this DiscoveryJobResult.
        :type: list[str]
        """
        self._sample_data_values = sample_data_values

    @property
    def app_defined_child_column_keys(self):
        """
        Gets the app_defined_child_column_keys of this DiscoveryJobResult.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.


        :return: The app_defined_child_column_keys of this DiscoveryJobResult.
        :rtype: list[str]
        """
        return self._app_defined_child_column_keys

    @app_defined_child_column_keys.setter
    def app_defined_child_column_keys(self, app_defined_child_column_keys):
        """
        Sets the app_defined_child_column_keys of this DiscoveryJobResult.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.


        :param app_defined_child_column_keys: The app_defined_child_column_keys of this DiscoveryJobResult.
        :type: list[str]
        """
        self._app_defined_child_column_keys = app_defined_child_column_keys

    @property
    def db_defined_child_column_keys(self):
        """
        Gets the db_defined_child_column_keys of this DiscoveryJobResult.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.


        :return: The db_defined_child_column_keys of this DiscoveryJobResult.
        :rtype: list[str]
        """
        return self._db_defined_child_column_keys

    @db_defined_child_column_keys.setter
    def db_defined_child_column_keys(self, db_defined_child_column_keys):
        """
        Sets the db_defined_child_column_keys of this DiscoveryJobResult.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.


        :param db_defined_child_column_keys: The db_defined_child_column_keys of this DiscoveryJobResult.
        :type: list[str]
        """
        self._db_defined_child_column_keys = db_defined_child_column_keys

    @property
    def planned_action(self):
        """
        **[Required]** Gets the planned_action of this DiscoveryJobResult.
        Specifies how to process the discovery result. It's set to NONE by default. Use the PatchDiscoveryJobResults operation to update this attribute. You can choose one of the following options:
        ACCEPT: To accept the discovery result and update the sensitive data model to reflect the changes.
        REJECT: To reject the discovery result so that it doesn't change the sensitive data model.
        INVALIDATE: To invalidate a newly discovered column. It adds the column to the sensitive data model but marks it as invalid. It helps track false positives and ensure that they aren't reported by future discovery jobs.
        After specifying the planned action, you can use the ApplyDiscoveryJobResults operation to automatically process the discovery results.

        Allowed values for this property are: "NONE", "ACCEPT", "INVALIDATE", "REJECT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The planned_action of this DiscoveryJobResult.
        :rtype: str
        """
        return self._planned_action

    @planned_action.setter
    def planned_action(self, planned_action):
        """
        Sets the planned_action of this DiscoveryJobResult.
        Specifies how to process the discovery result. It's set to NONE by default. Use the PatchDiscoveryJobResults operation to update this attribute. You can choose one of the following options:
        ACCEPT: To accept the discovery result and update the sensitive data model to reflect the changes.
        REJECT: To reject the discovery result so that it doesn't change the sensitive data model.
        INVALIDATE: To invalidate a newly discovered column. It adds the column to the sensitive data model but marks it as invalid. It helps track false positives and ensure that they aren't reported by future discovery jobs.
        After specifying the planned action, you can use the ApplyDiscoveryJobResults operation to automatically process the discovery results.


        :param planned_action: The planned_action of this DiscoveryJobResult.
        :type: str
        """
        allowed_values = ["NONE", "ACCEPT", "INVALIDATE", "REJECT"]
        if not value_allowed_none_or_none_sentinel(planned_action, allowed_values):
            planned_action = 'UNKNOWN_ENUM_VALUE'
        self._planned_action = planned_action

    @property
    def is_result_applied(self):
        """
        **[Required]** Gets the is_result_applied of this DiscoveryJobResult.
        Indicates if the discovery result has been processed. You can update this attribute using the PatchDiscoveryJobResults
        operation to track whether the discovery result has already been processed and applied to the sensitive data model.


        :return: The is_result_applied of this DiscoveryJobResult.
        :rtype: bool
        """
        return self._is_result_applied

    @is_result_applied.setter
    def is_result_applied(self, is_result_applied):
        """
        Sets the is_result_applied of this DiscoveryJobResult.
        Indicates if the discovery result has been processed. You can update this attribute using the PatchDiscoveryJobResults
        operation to track whether the discovery result has already been processed and applied to the sensitive data model.


        :param is_result_applied: The is_result_applied of this DiscoveryJobResult.
        :type: bool
        """
        self._is_result_applied = is_result_applied

    @property
    def modified_attributes(self):
        """
        Gets the modified_attributes of this DiscoveryJobResult.

        :return: The modified_attributes of this DiscoveryJobResult.
        :rtype: oci.data_safe.models.ModifiedAttributes
        """
        return self._modified_attributes

    @modified_attributes.setter
    def modified_attributes(self, modified_attributes):
        """
        Sets the modified_attributes of this DiscoveryJobResult.

        :param modified_attributes: The modified_attributes of this DiscoveryJobResult.
        :type: oci.data_safe.models.ModifiedAttributes
        """
        self._modified_attributes = modified_attributes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlTuningTaskPlanStats(object):
    """
    The statistics of a SQL execution plan.
    """

    #: A constant which can be used with the plan_status property of a SqlTuningTaskPlanStats.
    #: This constant has a value of "COMPLETE"
    PLAN_STATUS_COMPLETE = "COMPLETE"

    #: A constant which can be used with the plan_status property of a SqlTuningTaskPlanStats.
    #: This constant has a value of "PARTIAL"
    PLAN_STATUS_PARTIAL = "PARTIAL"

    def __init__(self, **kwargs):
        """
        Initializes a new SqlTuningTaskPlanStats object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param plan_type:
            The value to assign to the plan_type property of this SqlTuningTaskPlanStats.
        :type plan_type: str

        :param plan_stats:
            The value to assign to the plan_stats property of this SqlTuningTaskPlanStats.
        :type plan_stats: dict(str, float)

        :param plan_status:
            The value to assign to the plan_status property of this SqlTuningTaskPlanStats.
            Allowed values for this property are: "COMPLETE", "PARTIAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type plan_status: str

        """
        self.swagger_types = {
            'plan_type': 'str',
            'plan_stats': 'dict(str, float)',
            'plan_status': 'str'
        }

        self.attribute_map = {
            'plan_type': 'planType',
            'plan_stats': 'planStats',
            'plan_status': 'planStatus'
        }

        self._plan_type = None
        self._plan_stats = None
        self._plan_status = None

    @property
    def plan_type(self):
        """
        **[Required]** Gets the plan_type of this SqlTuningTaskPlanStats.
        The type of the original or modified plan with profile, index, and so on.


        :return: The plan_type of this SqlTuningTaskPlanStats.
        :rtype: str
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """
        Sets the plan_type of this SqlTuningTaskPlanStats.
        The type of the original or modified plan with profile, index, and so on.


        :param plan_type: The plan_type of this SqlTuningTaskPlanStats.
        :type: str
        """
        self._plan_type = plan_type

    @property
    def plan_stats(self):
        """
        **[Required]** Gets the plan_stats of this SqlTuningTaskPlanStats.
        A map contains the statistics for the SQL execution using the plan.
        The key of the map is the metric's name. The value of the map is the metric's value.


        :return: The plan_stats of this SqlTuningTaskPlanStats.
        :rtype: dict(str, float)
        """
        return self._plan_stats

    @plan_stats.setter
    def plan_stats(self, plan_stats):
        """
        Sets the plan_stats of this SqlTuningTaskPlanStats.
        A map contains the statistics for the SQL execution using the plan.
        The key of the map is the metric's name. The value of the map is the metric's value.


        :param plan_stats: The plan_stats of this SqlTuningTaskPlanStats.
        :type: dict(str, float)
        """
        self._plan_stats = plan_stats

    @property
    def plan_status(self):
        """
        **[Required]** Gets the plan_status of this SqlTuningTaskPlanStats.
        The status of the execution using the plan.

        Allowed values for this property are: "COMPLETE", "PARTIAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The plan_status of this SqlTuningTaskPlanStats.
        :rtype: str
        """
        return self._plan_status

    @plan_status.setter
    def plan_status(self, plan_status):
        """
        Sets the plan_status of this SqlTuningTaskPlanStats.
        The status of the execution using the plan.


        :param plan_status: The plan_status of this SqlTuningTaskPlanStats.
        :type: str
        """
        allowed_values = ["COMPLETE", "PARTIAL"]
        if not value_allowed_none_or_none_sentinel(plan_status, allowed_values):
            plan_status = 'UNKNOWN_ENUM_VALUE'
        self._plan_status = plan_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Cell(object):
    """
    A single cell in a table.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Cell object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param text:
            The value to assign to the text property of this Cell.
        :type text: str

        :param row_index:
            The value to assign to the row_index property of this Cell.
        :type row_index: int

        :param column_index:
            The value to assign to the column_index property of this Cell.
        :type column_index: int

        :param confidence:
            The value to assign to the confidence property of this Cell.
        :type confidence: float

        :param bounding_polygon:
            The value to assign to the bounding_polygon property of this Cell.
        :type bounding_polygon: oci.ai_vision.models.BoundingPolygon

        :param word_indexes:
            The value to assign to the word_indexes property of this Cell.
        :type word_indexes: list[int]

        """
        self.swagger_types = {
            'text': 'str',
            'row_index': 'int',
            'column_index': 'int',
            'confidence': 'float',
            'bounding_polygon': 'BoundingPolygon',
            'word_indexes': 'list[int]'
        }

        self.attribute_map = {
            'text': 'text',
            'row_index': 'rowIndex',
            'column_index': 'columnIndex',
            'confidence': 'confidence',
            'bounding_polygon': 'boundingPolygon',
            'word_indexes': 'wordIndexes'
        }

        self._text = None
        self._row_index = None
        self._column_index = None
        self._confidence = None
        self._bounding_polygon = None
        self._word_indexes = None

    @property
    def text(self):
        """
        **[Required]** Gets the text of this Cell.
        The text recognized in the cell.


        :return: The text of this Cell.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this Cell.
        The text recognized in the cell.


        :param text: The text of this Cell.
        :type: str
        """
        self._text = text

    @property
    def row_index(self):
        """
        **[Required]** Gets the row_index of this Cell.
        The index of the cell inside the row.


        :return: The row_index of this Cell.
        :rtype: int
        """
        return self._row_index

    @row_index.setter
    def row_index(self, row_index):
        """
        Sets the row_index of this Cell.
        The index of the cell inside the row.


        :param row_index: The row_index of this Cell.
        :type: int
        """
        self._row_index = row_index

    @property
    def column_index(self):
        """
        **[Required]** Gets the column_index of this Cell.
        The index of the cell inside the column.


        :return: The column_index of this Cell.
        :rtype: int
        """
        return self._column_index

    @column_index.setter
    def column_index(self, column_index):
        """
        Sets the column_index of this Cell.
        The index of the cell inside the column.


        :param column_index: The column_index of this Cell.
        :type: int
        """
        self._column_index = column_index

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this Cell.
        The confidence score between 0 and 1.


        :return: The confidence of this Cell.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this Cell.
        The confidence score between 0 and 1.


        :param confidence: The confidence of this Cell.
        :type: float
        """
        self._confidence = confidence

    @property
    def bounding_polygon(self):
        """
        **[Required]** Gets the bounding_polygon of this Cell.

        :return: The bounding_polygon of this Cell.
        :rtype: oci.ai_vision.models.BoundingPolygon
        """
        return self._bounding_polygon

    @bounding_polygon.setter
    def bounding_polygon(self, bounding_polygon):
        """
        Sets the bounding_polygon of this Cell.

        :param bounding_polygon: The bounding_polygon of this Cell.
        :type: oci.ai_vision.models.BoundingPolygon
        """
        self._bounding_polygon = bounding_polygon

    @property
    def word_indexes(self):
        """
        **[Required]** Gets the word_indexes of this Cell.
        The words detected in the cell.


        :return: The word_indexes of this Cell.
        :rtype: list[int]
        """
        return self._word_indexes

    @word_indexes.setter
    def word_indexes(self, word_indexes):
        """
        Sets the word_indexes of this Cell.
        The words detected in the cell.


        :param word_indexes: The word_indexes of this Cell.
        :type: list[int]
        """
        self._word_indexes = word_indexes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OdaInstanceAttachment(object):
    """
    Description of an ODA instance attachment.
    """

    #: A constant which can be used with the attachment_type property of a OdaInstanceAttachment.
    #: This constant has a value of "FUSION"
    ATTACHMENT_TYPE_FUSION = "FUSION"

    #: A constant which can be used with the lifecycle_state property of a OdaInstanceAttachment.
    #: This constant has a value of "ATTACHING"
    LIFECYCLE_STATE_ATTACHING = "ATTACHING"

    #: A constant which can be used with the lifecycle_state property of a OdaInstanceAttachment.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OdaInstanceAttachment.
    #: This constant has a value of "DETACHING"
    LIFECYCLE_STATE_DETACHING = "DETACHING"

    #: A constant which can be used with the lifecycle_state property of a OdaInstanceAttachment.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OdaInstanceAttachment.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new OdaInstanceAttachment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OdaInstanceAttachment.
        :type id: str

        :param instance_id:
            The value to assign to the instance_id property of this OdaInstanceAttachment.
        :type instance_id: str

        :param attach_to_id:
            The value to assign to the attach_to_id property of this OdaInstanceAttachment.
        :type attach_to_id: str

        :param attachment_type:
            The value to assign to the attachment_type property of this OdaInstanceAttachment.
            Allowed values for this property are: "FUSION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type attachment_type: str

        :param attachment_metadata:
            The value to assign to the attachment_metadata property of this OdaInstanceAttachment.
        :type attachment_metadata: str

        :param restricted_operations:
            The value to assign to the restricted_operations property of this OdaInstanceAttachment.
        :type restricted_operations: list[str]

        :param owner:
            The value to assign to the owner property of this OdaInstanceAttachment.
        :type owner: oci.oda.models.OdaInstanceOwner

        :param time_created:
            The value to assign to the time_created property of this OdaInstanceAttachment.
        :type time_created: datetime

        :param time_last_update:
            The value to assign to the time_last_update property of this OdaInstanceAttachment.
        :type time_last_update: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OdaInstanceAttachment.
            Allowed values for this property are: "ATTACHING", "ACTIVE", "DETACHING", "INACTIVE", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this OdaInstanceAttachment.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this OdaInstanceAttachment.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'instance_id': 'str',
            'attach_to_id': 'str',
            'attachment_type': 'str',
            'attachment_metadata': 'str',
            'restricted_operations': 'list[str]',
            'owner': 'OdaInstanceOwner',
            'time_created': 'datetime',
            'time_last_update': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'instance_id': 'instanceId',
            'attach_to_id': 'attachToId',
            'attachment_type': 'attachmentType',
            'attachment_metadata': 'attachmentMetadata',
            'restricted_operations': 'restrictedOperations',
            'owner': 'owner',
            'time_created': 'timeCreated',
            'time_last_update': 'timeLastUpdate',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._instance_id = None
        self._attach_to_id = None
        self._attachment_type = None
        self._attachment_metadata = None
        self._restricted_operations = None
        self._owner = None
        self._time_created = None
        self._time_last_update = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this OdaInstanceAttachment.
        Unique immutable identifier that was assigned when the ODA instance attachment was created.


        :return: The id of this OdaInstanceAttachment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OdaInstanceAttachment.
        Unique immutable identifier that was assigned when the ODA instance attachment was created.


        :param id: The id of this OdaInstanceAttachment.
        :type: str
        """
        self._id = id

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this OdaInstanceAttachment.
        The OCID of the ODA instance to which the attachment applies.


        :return: The instance_id of this OdaInstanceAttachment.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this OdaInstanceAttachment.
        The OCID of the ODA instance to which the attachment applies.


        :param instance_id: The instance_id of this OdaInstanceAttachment.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def attach_to_id(self):
        """
        **[Required]** Gets the attach_to_id of this OdaInstanceAttachment.
        The OCID of the target instance (which could be any other OCI PaaS/SaaS resource), to which the ODA instance is or is being attached.


        :return: The attach_to_id of this OdaInstanceAttachment.
        :rtype: str
        """
        return self._attach_to_id

    @attach_to_id.setter
    def attach_to_id(self, attach_to_id):
        """
        Sets the attach_to_id of this OdaInstanceAttachment.
        The OCID of the target instance (which could be any other OCI PaaS/SaaS resource), to which the ODA instance is or is being attached.


        :param attach_to_id: The attach_to_id of this OdaInstanceAttachment.
        :type: str
        """
        self._attach_to_id = attach_to_id

    @property
    def attachment_type(self):
        """
        **[Required]** Gets the attachment_type of this OdaInstanceAttachment.
        The type of attachment defined as an enum.

        Allowed values for this property are: "FUSION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The attachment_type of this OdaInstanceAttachment.
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """
        Sets the attachment_type of this OdaInstanceAttachment.
        The type of attachment defined as an enum.


        :param attachment_type: The attachment_type of this OdaInstanceAttachment.
        :type: str
        """
        allowed_values = ["FUSION"]
        if not value_allowed_none_or_none_sentinel(attachment_type, allowed_values):
            attachment_type = 'UNKNOWN_ENUM_VALUE'
        self._attachment_type = attachment_type

    @property
    def attachment_metadata(self):
        """
        Gets the attachment_metadata of this OdaInstanceAttachment.
        Attachment-specific metadata, defined by the target service.


        :return: The attachment_metadata of this OdaInstanceAttachment.
        :rtype: str
        """
        return self._attachment_metadata

    @attachment_metadata.setter
    def attachment_metadata(self, attachment_metadata):
        """
        Sets the attachment_metadata of this OdaInstanceAttachment.
        Attachment-specific metadata, defined by the target service.


        :param attachment_metadata: The attachment_metadata of this OdaInstanceAttachment.
        :type: str
        """
        self._attachment_metadata = attachment_metadata

    @property
    def restricted_operations(self):
        """
        Gets the restricted_operations of this OdaInstanceAttachment.
        List of operation names that are restricted while this ODA instance is attached.


        :return: The restricted_operations of this OdaInstanceAttachment.
        :rtype: list[str]
        """
        return self._restricted_operations

    @restricted_operations.setter
    def restricted_operations(self, restricted_operations):
        """
        Sets the restricted_operations of this OdaInstanceAttachment.
        List of operation names that are restricted while this ODA instance is attached.


        :param restricted_operations: The restricted_operations of this OdaInstanceAttachment.
        :type: list[str]
        """
        self._restricted_operations = restricted_operations

    @property
    def owner(self):
        """
        Gets the owner of this OdaInstanceAttachment.

        :return: The owner of this OdaInstanceAttachment.
        :rtype: oci.oda.models.OdaInstanceOwner
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this OdaInstanceAttachment.

        :param owner: The owner of this OdaInstanceAttachment.
        :type: oci.oda.models.OdaInstanceOwner
        """
        self._owner = owner

    @property
    def time_created(self):
        """
        Gets the time_created of this OdaInstanceAttachment.
        The time the attachment was created. An RFC3339 formatted datetime string


        :return: The time_created of this OdaInstanceAttachment.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this OdaInstanceAttachment.
        The time the attachment was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this OdaInstanceAttachment.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_update(self):
        """
        Gets the time_last_update of this OdaInstanceAttachment.
        The time the attachment was last modified. An RFC3339 formatted datetime string


        :return: The time_last_update of this OdaInstanceAttachment.
        :rtype: datetime
        """
        return self._time_last_update

    @time_last_update.setter
    def time_last_update(self, time_last_update):
        """
        Sets the time_last_update of this OdaInstanceAttachment.
        The time the attachment was last modified. An RFC3339 formatted datetime string


        :param time_last_update: The time_last_update of this OdaInstanceAttachment.
        :type: datetime
        """
        self._time_last_update = time_last_update

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this OdaInstanceAttachment.
        The current state of the attachment.

        Allowed values for this property are: "ATTACHING", "ACTIVE", "DETACHING", "INACTIVE", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this OdaInstanceAttachment.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this OdaInstanceAttachment.
        The current state of the attachment.


        :param lifecycle_state: The lifecycle_state of this OdaInstanceAttachment.
        :type: str
        """
        allowed_values = ["ATTACHING", "ACTIVE", "DETACHING", "INACTIVE", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this OdaInstanceAttachment.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this OdaInstanceAttachment.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this OdaInstanceAttachment.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this OdaInstanceAttachment.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this OdaInstanceAttachment.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this OdaInstanceAttachment.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this OdaInstanceAttachment.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this OdaInstanceAttachment.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Compartment(object):
    """
    Compartment model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Compartment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Compartment.
        :type id: str

        :param name:
            The value to assign to the name property of this Compartment.
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this Compartment.
        :type display_name: str

        :param full_name:
            The value to assign to the full_name property of this Compartment.
        :type full_name: str

        :param parent_compartment_id:
            The value to assign to the parent_compartment_id property of this Compartment.
        :type parent_compartment_id: str

        :param status:
            The value to assign to the status property of this Compartment.
        :type status: oci.identity_data_plane.models.EntityStatus

        :param property_map:
            The value to assign to the property_map property of this Compartment.
        :type property_map: dict(str, str)

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'display_name': 'str',
            'full_name': 'str',
            'parent_compartment_id': 'str',
            'status': 'EntityStatus',
            'property_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'display_name': 'displayName',
            'full_name': 'fullName',
            'parent_compartment_id': 'parentCompartmentId',
            'status': 'status',
            'property_map': 'propertyMap'
        }

        self._id = None
        self._name = None
        self._display_name = None
        self._full_name = None
        self._parent_compartment_id = None
        self._status = None
        self._property_map = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Compartment.
        The id of the compartment.


        :return: The id of this Compartment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Compartment.
        The id of the compartment.


        :param id: The id of this Compartment.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Compartment.
        The name of the compartment.


        :return: The name of this Compartment.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Compartment.
        The name of the compartment.


        :param name: The name of this Compartment.
        :type: str
        """
        self._name = name

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Compartment.
        The display name of the compartment.


        :return: The display_name of this Compartment.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Compartment.
        The display name of the compartment.


        :param display_name: The display_name of this Compartment.
        :type: str
        """
        self._display_name = display_name

    @property
    def full_name(self):
        """
        **[Required]** Gets the full_name of this Compartment.
        The full name of the compartment.


        :return: The full_name of this Compartment.
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """
        Sets the full_name of this Compartment.
        The full name of the compartment.


        :param full_name: The full_name of this Compartment.
        :type: str
        """
        self._full_name = full_name

    @property
    def parent_compartment_id(self):
        """
        **[Required]** Gets the parent_compartment_id of this Compartment.
        The id of the parent compartment.


        :return: The parent_compartment_id of this Compartment.
        :rtype: str
        """
        return self._parent_compartment_id

    @parent_compartment_id.setter
    def parent_compartment_id(self, parent_compartment_id):
        """
        Sets the parent_compartment_id of this Compartment.
        The id of the parent compartment.


        :param parent_compartment_id: The parent_compartment_id of this Compartment.
        :type: str
        """
        self._parent_compartment_id = parent_compartment_id

    @property
    def status(self):
        """
        **[Required]** Gets the status of this Compartment.
        The status of the compartment.


        :return: The status of this Compartment.
        :rtype: oci.identity_data_plane.models.EntityStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Compartment.
        The status of the compartment.


        :param status: The status of this Compartment.
        :type: oci.identity_data_plane.models.EntityStatus
        """
        self._status = status

    @property
    def property_map(self):
        """
        **[Required]** Gets the property_map of this Compartment.
        The extended properties.


        :return: The property_map of this Compartment.
        :rtype: dict(str, str)
        """
        return self._property_map

    @property_map.setter
    def property_map(self, property_map):
        """
        Sets the property_map of this Compartment.
        The extended properties.


        :param property_map: The property_map of this Compartment.
        :type: dict(str, str)
        """
        self._property_map = property_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProtectionCapability(object):
    """
    References an OCI-managed protection capability. Checks if HTTP requests/responses are malicious.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ProtectionCapability object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this ProtectionCapability.
        :type key: str

        :param version:
            The value to assign to the version property of this ProtectionCapability.
        :type version: int

        :param exclusions:
            The value to assign to the exclusions property of this ProtectionCapability.
        :type exclusions: oci.waf.models.ProtectionCapabilityExclusions

        :param action_name:
            The value to assign to the action_name property of this ProtectionCapability.
        :type action_name: str

        :param collaborative_action_threshold:
            The value to assign to the collaborative_action_threshold property of this ProtectionCapability.
        :type collaborative_action_threshold: int

        :param collaborative_weights:
            The value to assign to the collaborative_weights property of this ProtectionCapability.
        :type collaborative_weights: list[oci.waf.models.CollaborativeCapabilityWeightOverride]

        """
        self.swagger_types = {
            'key': 'str',
            'version': 'int',
            'exclusions': 'ProtectionCapabilityExclusions',
            'action_name': 'str',
            'collaborative_action_threshold': 'int',
            'collaborative_weights': 'list[CollaborativeCapabilityWeightOverride]'
        }

        self.attribute_map = {
            'key': 'key',
            'version': 'version',
            'exclusions': 'exclusions',
            'action_name': 'actionName',
            'collaborative_action_threshold': 'collaborativeActionThreshold',
            'collaborative_weights': 'collaborativeWeights'
        }

        self._key = None
        self._version = None
        self._exclusions = None
        self._action_name = None
        self._collaborative_action_threshold = None
        self._collaborative_weights = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this ProtectionCapability.
        Unique key of referenced protection capability.


        :return: The key of this ProtectionCapability.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ProtectionCapability.
        Unique key of referenced protection capability.


        :param key: The key of this ProtectionCapability.
        :type: str
        """
        self._key = key

    @property
    def version(self):
        """
        **[Required]** Gets the version of this ProtectionCapability.
        Version of referenced protection capability.


        :return: The version of this ProtectionCapability.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ProtectionCapability.
        Version of referenced protection capability.


        :param version: The version of this ProtectionCapability.
        :type: int
        """
        self._version = version

    @property
    def exclusions(self):
        """
        Gets the exclusions of this ProtectionCapability.

        :return: The exclusions of this ProtectionCapability.
        :rtype: oci.waf.models.ProtectionCapabilityExclusions
        """
        return self._exclusions

    @exclusions.setter
    def exclusions(self, exclusions):
        """
        Sets the exclusions of this ProtectionCapability.

        :param exclusions: The exclusions of this ProtectionCapability.
        :type: oci.waf.models.ProtectionCapabilityExclusions
        """
        self._exclusions = exclusions

    @property
    def action_name(self):
        """
        Gets the action_name of this ProtectionCapability.
        Override action to take if capability was triggered, defined in Protection Rule for this capability.
        Only actions of type CHECK are allowed.


        :return: The action_name of this ProtectionCapability.
        :rtype: str
        """
        return self._action_name

    @action_name.setter
    def action_name(self, action_name):
        """
        Sets the action_name of this ProtectionCapability.
        Override action to take if capability was triggered, defined in Protection Rule for this capability.
        Only actions of type CHECK are allowed.


        :param action_name: The action_name of this ProtectionCapability.
        :type: str
        """
        self._action_name = action_name

    @property
    def collaborative_action_threshold(self):
        """
        Gets the collaborative_action_threshold of this ProtectionCapability.
        The minimum sum of weights of associated collaborative protection capabilities that have triggered which
        must be reached in order for _this_ capability to trigger.
        This field is ignored for non-collaborative capabilities.


        :return: The collaborative_action_threshold of this ProtectionCapability.
        :rtype: int
        """
        return self._collaborative_action_threshold

    @collaborative_action_threshold.setter
    def collaborative_action_threshold(self, collaborative_action_threshold):
        """
        Sets the collaborative_action_threshold of this ProtectionCapability.
        The minimum sum of weights of associated collaborative protection capabilities that have triggered which
        must be reached in order for _this_ capability to trigger.
        This field is ignored for non-collaborative capabilities.


        :param collaborative_action_threshold: The collaborative_action_threshold of this ProtectionCapability.
        :type: int
        """
        self._collaborative_action_threshold = collaborative_action_threshold

    @property
    def collaborative_weights(self):
        """
        Gets the collaborative_weights of this ProtectionCapability.
        Explicit weight values to use for associated collaborative protection capabilities.


        :return: The collaborative_weights of this ProtectionCapability.
        :rtype: list[oci.waf.models.CollaborativeCapabilityWeightOverride]
        """
        return self._collaborative_weights

    @collaborative_weights.setter
    def collaborative_weights(self, collaborative_weights):
        """
        Sets the collaborative_weights of this ProtectionCapability.
        Explicit weight values to use for associated collaborative protection capabilities.


        :param collaborative_weights: The collaborative_weights of this ProtectionCapability.
        :type: list[oci.waf.models.CollaborativeCapabilityWeightOverride]
        """
        self._collaborative_weights = collaborative_weights

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateTagNamespaceDetails(object):
    """
    UpdateTagNamespaceDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateTagNamespaceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateTagNamespaceDetails.
        :type description: str

        :param is_retired:
            The value to assign to the is_retired property of this UpdateTagNamespaceDetails.
        :type is_retired: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateTagNamespaceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateTagNamespaceDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'description': 'str',
            'is_retired': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'description': 'description',
            'is_retired': 'isRetired',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._description = None
        self._is_retired = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def description(self):
        """
        Gets the description of this UpdateTagNamespaceDetails.
        The description you assign to the tag namespace.


        :return: The description of this UpdateTagNamespaceDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateTagNamespaceDetails.
        The description you assign to the tag namespace.


        :param description: The description of this UpdateTagNamespaceDetails.
        :type: str
        """
        self._description = description

    @property
    def is_retired(self):
        """
        Gets the is_retired of this UpdateTagNamespaceDetails.
        Whether the tag namespace is retired.
        See `Retiring Key Definitions and Namespace Definitions`__.

        __ https://docs.cloud.oracle.com/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm#retiringkeys


        :return: The is_retired of this UpdateTagNamespaceDetails.
        :rtype: bool
        """
        return self._is_retired

    @is_retired.setter
    def is_retired(self, is_retired):
        """
        Sets the is_retired of this UpdateTagNamespaceDetails.
        Whether the tag namespace is retired.
        See `Retiring Key Definitions and Namespace Definitions`__.

        __ https://docs.cloud.oracle.com/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm#retiringkeys


        :param is_retired: The is_retired of this UpdateTagNamespaceDetails.
        :type: bool
        """
        self._is_retired = is_retired

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateTagNamespaceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateTagNamespaceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateTagNamespaceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateTagNamespaceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateTagNamespaceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateTagNamespaceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateTagNamespaceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateTagNamespaceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateReportDefinitionDetails(object):
    """
    Description of a new report definition.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateReportDefinitionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateReportDefinitionDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateReportDefinitionDetails.
        :type display_name: str

        :param parent_id:
            The value to assign to the parent_id property of this CreateReportDefinitionDetails.
        :type parent_id: str

        :param description:
            The value to assign to the description property of this CreateReportDefinitionDetails.
        :type description: str

        :param column_info:
            The value to assign to the column_info property of this CreateReportDefinitionDetails.
        :type column_info: list[oci.data_safe.models.Column]

        :param column_filters:
            The value to assign to the column_filters property of this CreateReportDefinitionDetails.
        :type column_filters: list[oci.data_safe.models.ColumnFilter]

        :param column_sortings:
            The value to assign to the column_sortings property of this CreateReportDefinitionDetails.
        :type column_sortings: list[oci.data_safe.models.ColumnSorting]

        :param summary:
            The value to assign to the summary property of this CreateReportDefinitionDetails.
        :type summary: list[oci.data_safe.models.Summary]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateReportDefinitionDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateReportDefinitionDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'parent_id': 'str',
            'description': 'str',
            'column_info': 'list[Column]',
            'column_filters': 'list[ColumnFilter]',
            'column_sortings': 'list[ColumnSorting]',
            'summary': 'list[Summary]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'parent_id': 'parentId',
            'description': 'description',
            'column_info': 'columnInfo',
            'column_filters': 'columnFilters',
            'column_sortings': 'columnSortings',
            'summary': 'summary',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._parent_id = None
        self._description = None
        self._column_info = None
        self._column_filters = None
        self._column_sortings = None
        self._summary = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateReportDefinitionDetails.
        The OCID of the compartment containing the report definition.


        :return: The compartment_id of this CreateReportDefinitionDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateReportDefinitionDetails.
        The OCID of the compartment containing the report definition.


        :param compartment_id: The compartment_id of this CreateReportDefinitionDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateReportDefinitionDetails.
        Specifies the name of the report definition.


        :return: The display_name of this CreateReportDefinitionDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateReportDefinitionDetails.
        Specifies the name of the report definition.


        :param display_name: The display_name of this CreateReportDefinitionDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def parent_id(self):
        """
        **[Required]** Gets the parent_id of this CreateReportDefinitionDetails.
        The OCID of the parent report definition.


        :return: The parent_id of this CreateReportDefinitionDetails.
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """
        Sets the parent_id of this CreateReportDefinitionDetails.
        The OCID of the parent report definition.


        :param parent_id: The parent_id of this CreateReportDefinitionDetails.
        :type: str
        """
        self._parent_id = parent_id

    @property
    def description(self):
        """
        Gets the description of this CreateReportDefinitionDetails.
        A description of the report definition.


        :return: The description of this CreateReportDefinitionDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateReportDefinitionDetails.
        A description of the report definition.


        :param description: The description of this CreateReportDefinitionDetails.
        :type: str
        """
        self._description = description

    @property
    def column_info(self):
        """
        **[Required]** Gets the column_info of this CreateReportDefinitionDetails.
        An array of column objects in the order (left to right) displayed in the report. A column object stores all information about a column, including the name displayed on the UI, corresponding field name in the data source, data type of the column, and column visibility (if the column is visible to the user).


        :return: The column_info of this CreateReportDefinitionDetails.
        :rtype: list[oci.data_safe.models.Column]
        """
        return self._column_info

    @column_info.setter
    def column_info(self, column_info):
        """
        Sets the column_info of this CreateReportDefinitionDetails.
        An array of column objects in the order (left to right) displayed in the report. A column object stores all information about a column, including the name displayed on the UI, corresponding field name in the data source, data type of the column, and column visibility (if the column is visible to the user).


        :param column_info: The column_info of this CreateReportDefinitionDetails.
        :type: list[oci.data_safe.models.Column]
        """
        self._column_info = column_info

    @property
    def column_filters(self):
        """
        **[Required]** Gets the column_filters of this CreateReportDefinitionDetails.
        An array of column filter objects. A column Filter object stores all information about a column filter including field name, an operator, one or more expressions, if the filter is enabled, or if the filter is hidden.


        :return: The column_filters of this CreateReportDefinitionDetails.
        :rtype: list[oci.data_safe.models.ColumnFilter]
        """
        return self._column_filters

    @column_filters.setter
    def column_filters(self, column_filters):
        """
        Sets the column_filters of this CreateReportDefinitionDetails.
        An array of column filter objects. A column Filter object stores all information about a column filter including field name, an operator, one or more expressions, if the filter is enabled, or if the filter is hidden.


        :param column_filters: The column_filters of this CreateReportDefinitionDetails.
        :type: list[oci.data_safe.models.ColumnFilter]
        """
        self._column_filters = column_filters

    @property
    def column_sortings(self):
        """
        **[Required]** Gets the column_sortings of this CreateReportDefinitionDetails.
        An array of column sorting objects. Each column sorting object stores the column name to be sorted and if the sorting is in ascending order; sorting is done by the first column in the array, then by the second column in the array, etc.


        :return: The column_sortings of this CreateReportDefinitionDetails.
        :rtype: list[oci.data_safe.models.ColumnSorting]
        """
        return self._column_sortings

    @column_sortings.setter
    def column_sortings(self, column_sortings):
        """
        Sets the column_sortings of this CreateReportDefinitionDetails.
        An array of column sorting objects. Each column sorting object stores the column name to be sorted and if the sorting is in ascending order; sorting is done by the first column in the array, then by the second column in the array, etc.


        :param column_sortings: The column_sortings of this CreateReportDefinitionDetails.
        :type: list[oci.data_safe.models.ColumnSorting]
        """
        self._column_sortings = column_sortings

    @property
    def summary(self):
        """
        **[Required]** Gets the summary of this CreateReportDefinitionDetails.
        An array of report summary objects in the order (left to right)  displayed in the report.  A  report summary object stores all information about summary of report to be displayed, including the name displayed on UI, the display order, corresponding group by and count of values, summary visibility (if the summary is visible to user).


        :return: The summary of this CreateReportDefinitionDetails.
        :rtype: list[oci.data_safe.models.Summary]
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this CreateReportDefinitionDetails.
        An array of report summary objects in the order (left to right)  displayed in the report.  A  report summary object stores all information about summary of report to be displayed, including the name displayed on UI, the display order, corresponding group by and count of values, summary visibility (if the summary is visible to user).


        :param summary: The summary of this CreateReportDefinitionDetails.
        :type: list[oci.data_safe.models.Summary]
        """
        self._summary = summary

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateReportDefinitionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateReportDefinitionDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateReportDefinitionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateReportDefinitionDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateReportDefinitionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateReportDefinitionDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateReportDefinitionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateReportDefinitionDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AvailableAuditVolumeSummary(object):
    """
    Represents the audit data volume collected by Data Safe from the target database for the specified audit profile.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AvailableAuditVolumeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param audit_profile_id:
            The value to assign to the audit_profile_id property of this AvailableAuditVolumeSummary.
        :type audit_profile_id: str

        :param trail_location:
            The value to assign to the trail_location property of this AvailableAuditVolumeSummary.
        :type trail_location: str

        :param month_in_consideration:
            The value to assign to the month_in_consideration property of this AvailableAuditVolumeSummary.
        :type month_in_consideration: datetime

        :param volume:
            The value to assign to the volume property of this AvailableAuditVolumeSummary.
        :type volume: int

        """
        self.swagger_types = {
            'audit_profile_id': 'str',
            'trail_location': 'str',
            'month_in_consideration': 'datetime',
            'volume': 'int'
        }

        self.attribute_map = {
            'audit_profile_id': 'auditProfileId',
            'trail_location': 'trailLocation',
            'month_in_consideration': 'monthInConsideration',
            'volume': 'volume'
        }

        self._audit_profile_id = None
        self._trail_location = None
        self._month_in_consideration = None
        self._volume = None

    @property
    def audit_profile_id(self):
        """
        **[Required]** Gets the audit_profile_id of this AvailableAuditVolumeSummary.
        The OCID of the audit profile resource.


        :return: The audit_profile_id of this AvailableAuditVolumeSummary.
        :rtype: str
        """
        return self._audit_profile_id

    @audit_profile_id.setter
    def audit_profile_id(self, audit_profile_id):
        """
        Sets the audit_profile_id of this AvailableAuditVolumeSummary.
        The OCID of the audit profile resource.


        :param audit_profile_id: The audit_profile_id of this AvailableAuditVolumeSummary.
        :type: str
        """
        self._audit_profile_id = audit_profile_id

    @property
    def trail_location(self):
        """
        **[Required]** Gets the trail_location of this AvailableAuditVolumeSummary.
        Audit trail location on the target database from where the audit data is being collected by Data Safe.


        :return: The trail_location of this AvailableAuditVolumeSummary.
        :rtype: str
        """
        return self._trail_location

    @trail_location.setter
    def trail_location(self, trail_location):
        """
        Sets the trail_location of this AvailableAuditVolumeSummary.
        Audit trail location on the target database from where the audit data is being collected by Data Safe.


        :param trail_location: The trail_location of this AvailableAuditVolumeSummary.
        :type: str
        """
        self._trail_location = trail_location

    @property
    def month_in_consideration(self):
        """
        **[Required]** Gets the month_in_consideration of this AvailableAuditVolumeSummary.
        Represents the month under consideration for which aggregated audit data volume available at the target is computed.
        This field will be the UTC start of the day of the first day of the month for which the aggregate count corresponds to, in the format defined by RFC3339..
        For instance, the value of 01-01-2021T00:00:00Z represents Jan 2021.


        :return: The month_in_consideration of this AvailableAuditVolumeSummary.
        :rtype: datetime
        """
        return self._month_in_consideration

    @month_in_consideration.setter
    def month_in_consideration(self, month_in_consideration):
        """
        Sets the month_in_consideration of this AvailableAuditVolumeSummary.
        Represents the month under consideration for which aggregated audit data volume available at the target is computed.
        This field will be the UTC start of the day of the first day of the month for which the aggregate count corresponds to, in the format defined by RFC3339..
        For instance, the value of 01-01-2021T00:00:00Z represents Jan 2021.


        :param month_in_consideration: The month_in_consideration of this AvailableAuditVolumeSummary.
        :type: datetime
        """
        self._month_in_consideration = month_in_consideration

    @property
    def volume(self):
        """
        **[Required]** Gets the volume of this AvailableAuditVolumeSummary.
        Represents the aggregated audit data volume available in the audit trails on the target database which is yet to be collected by Data Safe for the specified month.


        :return: The volume of this AvailableAuditVolumeSummary.
        :rtype: int
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """
        Sets the volume of this AvailableAuditVolumeSummary.
        Represents the aggregated audit data volume available in the audit trails on the target database which is yet to be collected by Data Safe for the specified month.


        :param volume: The volume of this AvailableAuditVolumeSummary.
        :type: int
        """
        self._volume = volume

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RestCallConfig(object):
    """
    The REST API configuration.
    """

    #: A constant which can be used with the method_type property of a RestCallConfig.
    #: This constant has a value of "GET"
    METHOD_TYPE_GET = "GET"

    #: A constant which can be used with the method_type property of a RestCallConfig.
    #: This constant has a value of "POST"
    METHOD_TYPE_POST = "POST"

    #: A constant which can be used with the method_type property of a RestCallConfig.
    #: This constant has a value of "PATCH"
    METHOD_TYPE_PATCH = "PATCH"

    #: A constant which can be used with the method_type property of a RestCallConfig.
    #: This constant has a value of "DELETE"
    METHOD_TYPE_DELETE = "DELETE"

    #: A constant which can be used with the method_type property of a RestCallConfig.
    #: This constant has a value of "PUT"
    METHOD_TYPE_PUT = "PUT"

    def __init__(self, **kwargs):
        """
        Initializes a new RestCallConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param method_type:
            The value to assign to the method_type property of this RestCallConfig.
            Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"
        :type method_type: str

        :param request_headers:
            The value to assign to the request_headers property of this RestCallConfig.
        :type request_headers: dict(str, str)

        :param config_values:
            The value to assign to the config_values property of this RestCallConfig.
        :type config_values: oci.data_integration.models.ConfigValues

        """
        self.swagger_types = {
            'method_type': 'str',
            'request_headers': 'dict(str, str)',
            'config_values': 'ConfigValues'
        }

        self.attribute_map = {
            'method_type': 'methodType',
            'request_headers': 'requestHeaders',
            'config_values': 'configValues'
        }

        self._method_type = None
        self._request_headers = None
        self._config_values = None

    @property
    def method_type(self):
        """
        Gets the method_type of this RestCallConfig.
        The REST method to use.

        Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"


        :return: The method_type of this RestCallConfig.
        :rtype: str
        """
        return self._method_type

    @method_type.setter
    def method_type(self, method_type):
        """
        Sets the method_type of this RestCallConfig.
        The REST method to use.


        :param method_type: The method_type of this RestCallConfig.
        :type: str
        """
        allowed_values = ["GET", "POST", "PATCH", "DELETE", "PUT"]
        if not value_allowed_none_or_none_sentinel(method_type, allowed_values):
            raise ValueError(
                "Invalid value for `method_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._method_type = method_type

    @property
    def request_headers(self):
        """
        Gets the request_headers of this RestCallConfig.
        The headers for the REST call.


        :return: The request_headers of this RestCallConfig.
        :rtype: dict(str, str)
        """
        return self._request_headers

    @request_headers.setter
    def request_headers(self, request_headers):
        """
        Sets the request_headers of this RestCallConfig.
        The headers for the REST call.


        :param request_headers: The request_headers of this RestCallConfig.
        :type: dict(str, str)
        """
        self._request_headers = request_headers

    @property
    def config_values(self):
        """
        Gets the config_values of this RestCallConfig.

        :return: The config_values of this RestCallConfig.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._config_values

    @config_values.setter
    def config_values(self, config_values):
        """
        Sets the config_values of this RestCallConfig.

        :param config_values: The config_values of this RestCallConfig.
        :type: oci.data_integration.models.ConfigValues
        """
        self._config_values = config_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputedUsageAggregatedSummary(object):
    """
    Subscribed Service Contract details
    """

    #: A constant which can be used with the pricing_model property of a ComputedUsageAggregatedSummary.
    #: This constant has a value of "PAY_AS_YOU_GO"
    PRICING_MODEL_PAY_AS_YOU_GO = "PAY_AS_YOU_GO"

    #: A constant which can be used with the pricing_model property of a ComputedUsageAggregatedSummary.
    #: This constant has a value of "MONTHLY"
    PRICING_MODEL_MONTHLY = "MONTHLY"

    #: A constant which can be used with the pricing_model property of a ComputedUsageAggregatedSummary.
    #: This constant has a value of "ANNUAL"
    PRICING_MODEL_ANNUAL = "ANNUAL"

    #: A constant which can be used with the pricing_model property of a ComputedUsageAggregatedSummary.
    #: This constant has a value of "PREPAID"
    PRICING_MODEL_PREPAID = "PREPAID"

    #: A constant which can be used with the pricing_model property of a ComputedUsageAggregatedSummary.
    #: This constant has a value of "FUNDED_ALLOCATION"
    PRICING_MODEL_FUNDED_ALLOCATION = "FUNDED_ALLOCATION"

    def __init__(self, **kwargs):
        """
        Initializes a new ComputedUsageAggregatedSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param subscription_id:
            The value to assign to the subscription_id property of this ComputedUsageAggregatedSummary.
        :type subscription_id: str

        :param parent_subscribed_service_id:
            The value to assign to the parent_subscribed_service_id property of this ComputedUsageAggregatedSummary.
        :type parent_subscribed_service_id: str

        :param parent_product:
            The value to assign to the parent_product property of this ComputedUsageAggregatedSummary.
        :type parent_product: oci.osub_usage.models.Product

        :param time_start:
            The value to assign to the time_start property of this ComputedUsageAggregatedSummary.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this ComputedUsageAggregatedSummary.
        :type time_end: datetime

        :param plan_number:
            The value to assign to the plan_number property of this ComputedUsageAggregatedSummary.
        :type plan_number: str

        :param currency_code:
            The value to assign to the currency_code property of this ComputedUsageAggregatedSummary.
        :type currency_code: str

        :param rate_card_id:
            The value to assign to the rate_card_id property of this ComputedUsageAggregatedSummary.
        :type rate_card_id: str

        :param pricing_model:
            The value to assign to the pricing_model property of this ComputedUsageAggregatedSummary.
            Allowed values for this property are: "PAY_AS_YOU_GO", "MONTHLY", "ANNUAL", "PREPAID", "FUNDED_ALLOCATION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type pricing_model: str

        :param aggregated_computed_usages:
            The value to assign to the aggregated_computed_usages property of this ComputedUsageAggregatedSummary.
        :type aggregated_computed_usages: list[oci.osub_usage.models.ComputedUsageAggregation]

        """
        self.swagger_types = {
            'subscription_id': 'str',
            'parent_subscribed_service_id': 'str',
            'parent_product': 'Product',
            'time_start': 'datetime',
            'time_end': 'datetime',
            'plan_number': 'str',
            'currency_code': 'str',
            'rate_card_id': 'str',
            'pricing_model': 'str',
            'aggregated_computed_usages': 'list[ComputedUsageAggregation]'
        }

        self.attribute_map = {
            'subscription_id': 'subscriptionId',
            'parent_subscribed_service_id': 'parentSubscribedServiceId',
            'parent_product': 'parentProduct',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'plan_number': 'planNumber',
            'currency_code': 'currencyCode',
            'rate_card_id': 'rateCardId',
            'pricing_model': 'pricingModel',
            'aggregated_computed_usages': 'aggregatedComputedUsages'
        }

        self._subscription_id = None
        self._parent_subscribed_service_id = None
        self._parent_product = None
        self._time_start = None
        self._time_end = None
        self._plan_number = None
        self._currency_code = None
        self._rate_card_id = None
        self._pricing_model = None
        self._aggregated_computed_usages = None

    @property
    def subscription_id(self):
        """
        **[Required]** Gets the subscription_id of this ComputedUsageAggregatedSummary.
        Subscription Id is an identifier associated to the service used for filter the Computed Usage in SPM


        :return: The subscription_id of this ComputedUsageAggregatedSummary.
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """
        Sets the subscription_id of this ComputedUsageAggregatedSummary.
        Subscription Id is an identifier associated to the service used for filter the Computed Usage in SPM


        :param subscription_id: The subscription_id of this ComputedUsageAggregatedSummary.
        :type: str
        """
        self._subscription_id = subscription_id

    @property
    def parent_subscribed_service_id(self):
        """
        Gets the parent_subscribed_service_id of this ComputedUsageAggregatedSummary.
        Subscribed service line parent id


        :return: The parent_subscribed_service_id of this ComputedUsageAggregatedSummary.
        :rtype: str
        """
        return self._parent_subscribed_service_id

    @parent_subscribed_service_id.setter
    def parent_subscribed_service_id(self, parent_subscribed_service_id):
        """
        Sets the parent_subscribed_service_id of this ComputedUsageAggregatedSummary.
        Subscribed service line parent id


        :param parent_subscribed_service_id: The parent_subscribed_service_id of this ComputedUsageAggregatedSummary.
        :type: str
        """
        self._parent_subscribed_service_id = parent_subscribed_service_id

    @property
    def parent_product(self):
        """
        Gets the parent_product of this ComputedUsageAggregatedSummary.

        :return: The parent_product of this ComputedUsageAggregatedSummary.
        :rtype: oci.osub_usage.models.Product
        """
        return self._parent_product

    @parent_product.setter
    def parent_product(self, parent_product):
        """
        Sets the parent_product of this ComputedUsageAggregatedSummary.

        :param parent_product: The parent_product of this ComputedUsageAggregatedSummary.
        :type: oci.osub_usage.models.Product
        """
        self._parent_product = parent_product

    @property
    def time_start(self):
        """
        Gets the time_start of this ComputedUsageAggregatedSummary.
        Subscribed services contract line start date, expressed in RFC 3339 timestamp format.


        :return: The time_start of this ComputedUsageAggregatedSummary.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this ComputedUsageAggregatedSummary.
        Subscribed services contract line start date, expressed in RFC 3339 timestamp format.


        :param time_start: The time_start of this ComputedUsageAggregatedSummary.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this ComputedUsageAggregatedSummary.
        Subscribed services contract line end date, expressed in RFC 3339 timestamp format.


        :return: The time_end of this ComputedUsageAggregatedSummary.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this ComputedUsageAggregatedSummary.
        Subscribed services contract line end date, expressed in RFC 3339 timestamp format.


        :param time_end: The time_end of this ComputedUsageAggregatedSummary.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def plan_number(self):
        """
        Gets the plan_number of this ComputedUsageAggregatedSummary.
        Subscribed service asociated subscription plan number.


        :return: The plan_number of this ComputedUsageAggregatedSummary.
        :rtype: str
        """
        return self._plan_number

    @plan_number.setter
    def plan_number(self, plan_number):
        """
        Sets the plan_number of this ComputedUsageAggregatedSummary.
        Subscribed service asociated subscription plan number.


        :param plan_number: The plan_number of this ComputedUsageAggregatedSummary.
        :type: str
        """
        self._plan_number = plan_number

    @property
    def currency_code(self):
        """
        Gets the currency_code of this ComputedUsageAggregatedSummary.
        Currency code


        :return: The currency_code of this ComputedUsageAggregatedSummary.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this ComputedUsageAggregatedSummary.
        Currency code


        :param currency_code: The currency_code of this ComputedUsageAggregatedSummary.
        :type: str
        """
        self._currency_code = currency_code

    @property
    def rate_card_id(self):
        """
        Gets the rate_card_id of this ComputedUsageAggregatedSummary.
        Inernal SPM Ratecard Id at line level


        :return: The rate_card_id of this ComputedUsageAggregatedSummary.
        :rtype: str
        """
        return self._rate_card_id

    @rate_card_id.setter
    def rate_card_id(self, rate_card_id):
        """
        Sets the rate_card_id of this ComputedUsageAggregatedSummary.
        Inernal SPM Ratecard Id at line level


        :param rate_card_id: The rate_card_id of this ComputedUsageAggregatedSummary.
        :type: str
        """
        self._rate_card_id = rate_card_id

    @property
    def pricing_model(self):
        """
        Gets the pricing_model of this ComputedUsageAggregatedSummary.
        Subscribed services pricing model

        Allowed values for this property are: "PAY_AS_YOU_GO", "MONTHLY", "ANNUAL", "PREPAID", "FUNDED_ALLOCATION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The pricing_model of this ComputedUsageAggregatedSummary.
        :rtype: str
        """
        return self._pricing_model

    @pricing_model.setter
    def pricing_model(self, pricing_model):
        """
        Sets the pricing_model of this ComputedUsageAggregatedSummary.
        Subscribed services pricing model


        :param pricing_model: The pricing_model of this ComputedUsageAggregatedSummary.
        :type: str
        """
        allowed_values = ["PAY_AS_YOU_GO", "MONTHLY", "ANNUAL", "PREPAID", "FUNDED_ALLOCATION"]
        if not value_allowed_none_or_none_sentinel(pricing_model, allowed_values):
            pricing_model = 'UNKNOWN_ENUM_VALUE'
        self._pricing_model = pricing_model

    @property
    def aggregated_computed_usages(self):
        """
        Gets the aggregated_computed_usages of this ComputedUsageAggregatedSummary.
        Aggregation of computed usages for the subscribed service.


        :return: The aggregated_computed_usages of this ComputedUsageAggregatedSummary.
        :rtype: list[oci.osub_usage.models.ComputedUsageAggregation]
        """
        return self._aggregated_computed_usages

    @aggregated_computed_usages.setter
    def aggregated_computed_usages(self, aggregated_computed_usages):
        """
        Sets the aggregated_computed_usages of this ComputedUsageAggregatedSummary.
        Aggregation of computed usages for the subscribed service.


        :param aggregated_computed_usages: The aggregated_computed_usages of this ComputedUsageAggregatedSummary.
        :type: list[oci.osub_usage.models.ComputedUsageAggregation]
        """
        self._aggregated_computed_usages = aggregated_computed_usages

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExportFormat(object):
    """
    Specifies the export format to be used for exporting snapshot.
    """

    #: A constant which can be used with the name property of a ExportFormat.
    #: This constant has a value of "JSONL"
    NAME_JSONL = "JSONL"

    #: A constant which can be used with the name property of a ExportFormat.
    #: This constant has a value of "JSONL_CONSOLIDATED"
    NAME_JSONL_CONSOLIDATED = "JSONL_CONSOLIDATED"

    #: A constant which can be used with the name property of a ExportFormat.
    #: This constant has a value of "CONLL"
    NAME_CONLL = "CONLL"

    #: A constant which can be used with the name property of a ExportFormat.
    #: This constant has a value of "SPACY"
    NAME_SPACY = "SPACY"

    #: A constant which can be used with the name property of a ExportFormat.
    #: This constant has a value of "COCO"
    NAME_COCO = "COCO"

    #: A constant which can be used with the name property of a ExportFormat.
    #: This constant has a value of "YOLO"
    NAME_YOLO = "YOLO"

    #: A constant which can be used with the name property of a ExportFormat.
    #: This constant has a value of "PASCAL_VOC"
    NAME_PASCAL_VOC = "PASCAL_VOC"

    #: A constant which can be used with the version property of a ExportFormat.
    #: This constant has a value of "V2003"
    VERSION_V2003 = "V2003"

    #: A constant which can be used with the version property of a ExportFormat.
    #: This constant has a value of "V5"
    VERSION_V5 = "V5"

    def __init__(self, **kwargs):
        """
        Initializes a new ExportFormat object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ExportFormat.
            Allowed values for this property are: "JSONL", "JSONL_CONSOLIDATED", "CONLL", "SPACY", "COCO", "YOLO", "PASCAL_VOC"
        :type name: str

        :param version:
            The value to assign to the version property of this ExportFormat.
            Allowed values for this property are: "V2003", "V5"
        :type version: str

        """
        self.swagger_types = {
            'name': 'str',
            'version': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'version': 'version'
        }

        self._name = None
        self._version = None

    @property
    def name(self):
        """
        Gets the name of this ExportFormat.
        Name of export format.

        Allowed values for this property are: "JSONL", "JSONL_CONSOLIDATED", "CONLL", "SPACY", "COCO", "YOLO", "PASCAL_VOC"


        :return: The name of this ExportFormat.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExportFormat.
        Name of export format.


        :param name: The name of this ExportFormat.
        :type: str
        """
        allowed_values = ["JSONL", "JSONL_CONSOLIDATED", "CONLL", "SPACY", "COCO", "YOLO", "PASCAL_VOC"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            raise ValueError(
                "Invalid value for `name`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this ExportFormat.
        Version of export format.

        Allowed values for this property are: "V2003", "V5"


        :return: The version of this ExportFormat.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ExportFormat.
        Version of export format.


        :param version: The version of this ExportFormat.
        :type: str
        """
        allowed_values = ["V2003", "V5"]
        if not value_allowed_none_or_none_sentinel(version, allowed_values):
            raise ValueError(
                "Invalid value for `version`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_database_tools_connection_details import UpdateDatabaseToolsConnectionDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDatabaseToolsConnectionOracleDatabaseDetails(UpdateDatabaseToolsConnectionDetails):
    """
    The information about new DatabaseToolsConnection for an Oracle Database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDatabaseToolsConnectionOracleDatabaseDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database_tools.models.UpdateDatabaseToolsConnectionOracleDatabaseDetails.type` attribute
        of this class is ``ORACLE_DATABASE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type display_name: str

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type freeform_tags: dict(str, str)

        :param type:
            The value to assign to the type property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
            Allowed values for this property are: "ORACLE_DATABASE"
        :type type: str

        :param related_resource:
            The value to assign to the related_resource property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type related_resource: oci.database_tools.models.UpdateDatabaseToolsRelatedResourceDetails

        :param connection_string:
            The value to assign to the connection_string property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type connection_string: str

        :param user_name:
            The value to assign to the user_name property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type user_name: str

        :param user_password:
            The value to assign to the user_password property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type user_password: oci.database_tools.models.DatabaseToolsUserPasswordDetails

        :param advanced_properties:
            The value to assign to the advanced_properties property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type advanced_properties: dict(str, str)

        :param key_stores:
            The value to assign to the key_stores property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type key_stores: list[oci.database_tools.models.DatabaseToolsKeyStoreDetails]

        :param private_endpoint_id:
            The value to assign to the private_endpoint_id property of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type private_endpoint_id: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'type': 'str',
            'related_resource': 'UpdateDatabaseToolsRelatedResourceDetails',
            'connection_string': 'str',
            'user_name': 'str',
            'user_password': 'DatabaseToolsUserPasswordDetails',
            'advanced_properties': 'dict(str, str)',
            'key_stores': 'list[DatabaseToolsKeyStoreDetails]',
            'private_endpoint_id': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'type': 'type',
            'related_resource': 'relatedResource',
            'connection_string': 'connectionString',
            'user_name': 'userName',
            'user_password': 'userPassword',
            'advanced_properties': 'advancedProperties',
            'key_stores': 'keyStores',
            'private_endpoint_id': 'privateEndpointId'
        }

        self._display_name = None
        self._defined_tags = None
        self._freeform_tags = None
        self._type = None
        self._related_resource = None
        self._connection_string = None
        self._user_name = None
        self._user_password = None
        self._advanced_properties = None
        self._key_stores = None
        self._private_endpoint_id = None
        self._type = 'ORACLE_DATABASE'

    @property
    def related_resource(self):
        """
        Gets the related_resource of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.

        :return: The related_resource of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :rtype: oci.database_tools.models.UpdateDatabaseToolsRelatedResourceDetails
        """
        return self._related_resource

    @related_resource.setter
    def related_resource(self, related_resource):
        """
        Sets the related_resource of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.

        :param related_resource: The related_resource of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type: oci.database_tools.models.UpdateDatabaseToolsRelatedResourceDetails
        """
        self._related_resource = related_resource

    @property
    def connection_string(self):
        """
        Gets the connection_string of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Connect descriptor or Easy Connect Naming method to connect to the database.


        :return: The connection_string of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """
        Sets the connection_string of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Connect descriptor or Easy Connect Naming method to connect to the database.


        :param connection_string: The connection_string of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type: str
        """
        self._connection_string = connection_string

    @property
    def user_name(self):
        """
        Gets the user_name of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Database user name.


        :return: The user_name of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Database user name.


        :param user_name: The user_name of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type: str
        """
        self._user_name = user_name

    @property
    def user_password(self):
        """
        Gets the user_password of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.

        :return: The user_password of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :rtype: oci.database_tools.models.DatabaseToolsUserPasswordDetails
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """
        Sets the user_password of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.

        :param user_password: The user_password of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type: oci.database_tools.models.DatabaseToolsUserPasswordDetails
        """
        self._user_password = user_password

    @property
    def advanced_properties(self):
        """
        Gets the advanced_properties of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Advanced connection properties key-value pair (e.g., oracle.net.ssl_server_dn_match).


        :return: The advanced_properties of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :rtype: dict(str, str)
        """
        return self._advanced_properties

    @advanced_properties.setter
    def advanced_properties(self, advanced_properties):
        """
        Sets the advanced_properties of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Advanced connection properties key-value pair (e.g., oracle.net.ssl_server_dn_match).


        :param advanced_properties: The advanced_properties of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type: dict(str, str)
        """
        self._advanced_properties = advanced_properties

    @property
    def key_stores(self):
        """
        Gets the key_stores of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Oracle wallet or Java Keystores containing trusted certificates for authenticating the server's public certificate and
        the client private key and associated certificates required for client authentication.


        :return: The key_stores of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :rtype: list[oci.database_tools.models.DatabaseToolsKeyStoreDetails]
        """
        return self._key_stores

    @key_stores.setter
    def key_stores(self, key_stores):
        """
        Sets the key_stores of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        Oracle wallet or Java Keystores containing trusted certificates for authenticating the server's public certificate and
        the client private key and associated certificates required for client authentication.


        :param key_stores: The key_stores of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type: list[oci.database_tools.models.DatabaseToolsKeyStoreDetails]
        """
        self._key_stores = key_stores

    @property
    def private_endpoint_id(self):
        """
        Gets the private_endpoint_id of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        The `OCID`__ of the DatabaseToolsPrivateEndpoint used to access the database in the Customer VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The private_endpoint_id of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :rtype: str
        """
        return self._private_endpoint_id

    @private_endpoint_id.setter
    def private_endpoint_id(self, private_endpoint_id):
        """
        Sets the private_endpoint_id of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        The `OCID`__ of the DatabaseToolsPrivateEndpoint used to access the database in the Customer VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param private_endpoint_id: The private_endpoint_id of this UpdateDatabaseToolsConnectionOracleDatabaseDetails.
        :type: str
        """
        self._private_endpoint_id = private_endpoint_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IdentityProvider(object):
    """
    IdentityProvider model.
    """

    #: A constant which can be used with the protocol property of a IdentityProvider.
    #: This constant has a value of "SAML2"
    PROTOCOL_SAML2 = "SAML2"

    def __init__(self, **kwargs):
        """
        Initializes a new IdentityProvider object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this IdentityProvider.
        :type id: str

        :param name:
            The value to assign to the name property of this IdentityProvider.
        :type name: str

        :param tenant_name:
            The value to assign to the tenant_name property of this IdentityProvider.
        :type tenant_name: str

        :param tenant_id:
            The value to assign to the tenant_id property of this IdentityProvider.
        :type tenant_id: str

        :param redirect_uri:
            The value to assign to the redirect_uri property of this IdentityProvider.
        :type redirect_uri: str

        :param signing_certificate:
            The value to assign to the signing_certificate property of this IdentityProvider.
        :type signing_certificate: str

        :param protocol:
            The value to assign to the protocol property of this IdentityProvider.
            Allowed values for this property are: "SAML2"
        :type protocol: str

        :param service_provider_entity_id:
            The value to assign to the service_provider_entity_id property of this IdentityProvider.
        :type service_provider_entity_id: str

        :param force_authentication:
            The value to assign to the force_authentication property of this IdentityProvider.
        :type force_authentication: bool

        :param authn_context_class_refs:
            The value to assign to the authn_context_class_refs property of this IdentityProvider.
        :type authn_context_class_refs: list[str]

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'tenant_name': 'str',
            'tenant_id': 'str',
            'redirect_uri': 'str',
            'signing_certificate': 'str',
            'protocol': 'str',
            'service_provider_entity_id': 'str',
            'force_authentication': 'bool',
            'authn_context_class_refs': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'tenant_name': 'tenantName',
            'tenant_id': 'tenantId',
            'redirect_uri': 'redirectUri',
            'signing_certificate': 'signingCertificate',
            'protocol': 'protocol',
            'service_provider_entity_id': 'serviceProviderEntityId',
            'force_authentication': 'forceAuthentication',
            'authn_context_class_refs': 'authnContextClassRefs'
        }

        self._id = None
        self._name = None
        self._tenant_name = None
        self._tenant_id = None
        self._redirect_uri = None
        self._signing_certificate = None
        self._protocol = None
        self._service_provider_entity_id = None
        self._force_authentication = None
        self._authn_context_class_refs = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this IdentityProvider.
        The id of the provider.


        :return: The id of this IdentityProvider.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IdentityProvider.
        The id of the provider.


        :param id: The id of this IdentityProvider.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this IdentityProvider.
        The name of the provider.


        :return: The name of this IdentityProvider.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IdentityProvider.
        The name of the provider.


        :param name: The name of this IdentityProvider.
        :type: str
        """
        self._name = name

    @property
    def tenant_name(self):
        """
        **[Required]** Gets the tenant_name of this IdentityProvider.
        The name of the tenant.


        :return: The tenant_name of this IdentityProvider.
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """
        Sets the tenant_name of this IdentityProvider.
        The name of the tenant.


        :param tenant_name: The tenant_name of this IdentityProvider.
        :type: str
        """
        self._tenant_name = tenant_name

    @property
    def tenant_id(self):
        """
        **[Required]** Gets the tenant_id of this IdentityProvider.
        The id of the tenant.


        :return: The tenant_id of this IdentityProvider.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this IdentityProvider.
        The id of the tenant.


        :param tenant_id: The tenant_id of this IdentityProvider.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def redirect_uri(self):
        """
        **[Required]** Gets the redirect_uri of this IdentityProvider.
        The SAML endpoint where user will be redirected.


        :return: The redirect_uri of this IdentityProvider.
        :rtype: str
        """
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, redirect_uri):
        """
        Sets the redirect_uri of this IdentityProvider.
        The SAML endpoint where user will be redirected.


        :param redirect_uri: The redirect_uri of this IdentityProvider.
        :type: str
        """
        self._redirect_uri = redirect_uri

    @property
    def signing_certificate(self):
        """
        **[Required]** Gets the signing_certificate of this IdentityProvider.
        The signing certificate of the provider.


        :return: The signing_certificate of this IdentityProvider.
        :rtype: str
        """
        return self._signing_certificate

    @signing_certificate.setter
    def signing_certificate(self, signing_certificate):
        """
        Sets the signing_certificate of this IdentityProvider.
        The signing certificate of the provider.


        :param signing_certificate: The signing_certificate of this IdentityProvider.
        :type: str
        """
        self._signing_certificate = signing_certificate

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this IdentityProvider.
        The type of the provider.

        Allowed values for this property are: "SAML2"


        :return: The protocol of this IdentityProvider.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this IdentityProvider.
        The type of the provider.


        :param protocol: The protocol of this IdentityProvider.
        :type: str
        """
        allowed_values = ["SAML2"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            raise ValueError(
                "Invalid value for `protocol`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._protocol = protocol

    @property
    def service_provider_entity_id(self):
        """
        **[Required]** Gets the service_provider_entity_id of this IdentityProvider.
        The id of the service provider entity.


        :return: The service_provider_entity_id of this IdentityProvider.
        :rtype: str
        """
        return self._service_provider_entity_id

    @service_provider_entity_id.setter
    def service_provider_entity_id(self, service_provider_entity_id):
        """
        Sets the service_provider_entity_id of this IdentityProvider.
        The id of the service provider entity.


        :param service_provider_entity_id: The service_provider_entity_id of this IdentityProvider.
        :type: str
        """
        self._service_provider_entity_id = service_provider_entity_id

    @property
    def force_authentication(self):
        """
        **[Required]** Gets the force_authentication of this IdentityProvider.
        Whether to force authentication.


        :return: The force_authentication of this IdentityProvider.
        :rtype: bool
        """
        return self._force_authentication

    @force_authentication.setter
    def force_authentication(self, force_authentication):
        """
        Sets the force_authentication of this IdentityProvider.
        Whether to force authentication.


        :param force_authentication: The force_authentication of this IdentityProvider.
        :type: bool
        """
        self._force_authentication = force_authentication

    @property
    def authn_context_class_refs(self):
        """
        **[Required]** Gets the authn_context_class_refs of this IdentityProvider.
        Authentication context class refs.


        :return: The authn_context_class_refs of this IdentityProvider.
        :rtype: list[str]
        """
        return self._authn_context_class_refs

    @authn_context_class_refs.setter
    def authn_context_class_refs(self, authn_context_class_refs):
        """
        Sets the authn_context_class_refs of this IdentityProvider.
        Authentication context class refs.


        :param authn_context_class_refs: The authn_context_class_refs of this IdentityProvider.
        :type: list[str]
        """
        self._authn_context_class_refs = authn_context_class_refs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
